prova

Dependencies:   BLE_API X_NUCLEO_IDB0XA1 X_NUCLEO_IKS01A2 mbed

Fork of BLE_HeartRate_IDB0XA1 by ST

Revision:
21:0e7c08f5386f
Parent:
14:f715c13eb84f
Child:
22:07ff2f7adb16
diff -r 60d60ccf8eea -r 0e7c08f5386f main.cpp
--- a/main.cpp	Fri Sep 16 10:21:57 2016 +0000
+++ b/main.cpp	Wed Oct 05 09:16:58 2016 +0000
@@ -63,7 +63,7 @@
     ble.gap().onDisconnection(disconnectionCallback);
 
     /* Setup primary service. */
-    uint8_t hrmCounter = 100; // init HRM to 100bps
+    uint8_t hrmCounter = 60; // init HRM to 60bps
     HeartRateService hrService(ble, hrmCounter, HeartRateService::LOCATION_FINGER);
 
     /* Setup advertising. */
@@ -85,9 +85,9 @@
             // In our case, we simply update the HRM measurement.
             hrmCounter++;
 
-            //  100 <= HRM bps <=175
-            if (hrmCounter == 175) {
-                hrmCounter = 100;
+            //  60 <= HRM bps <= 100
+            if (hrmCounter == 100) {
+                hrmCounter = 60;
             }
 
             // update bps